summaryrefslogtreecommitdiffstats
path: root/interfaces/khexedit/byteseditinterface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /interfaces/khexedit/byteseditinterface.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'interfaces/khexedit/byteseditinterface.h')
-rw-r--r--interfaces/khexedit/byteseditinterface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/interfaces/khexedit/byteseditinterface.h b/interfaces/khexedit/byteseditinterface.h
index f2ec1e7bd..dc0a9dca5 100644
--- a/interfaces/khexedit/byteseditinterface.h
+++ b/interfaces/khexedit/byteseditinterface.h
@@ -143,8 +143,8 @@ class BytesEditInterface
virtual bool isModified() const = 0;
public: // call for action
- /** tqrepaint the indizes from i1 to i2 */
- virtual void tqrepaintRange( int i1, int i2 ) = 0;
+ /** repaint the indizes from i1 to i2 */
+ virtual void repaintRange( int i1, int i2 ) = 0;
};
@@ -221,7 +221,7 @@ inline BytesEditInterface *bytesEditInterface( T *t )
inline TQWidget *createBytesEditWidget( TQWidget *Parent = 0, const char *Name = 0 )
{
return KParts::ComponentFactory::createInstanceFromQuery<TQWidget>
- ( TQString::tqfromLatin1("KHexEdit/KBytesEdit"), TQString::null, Parent, Name );
+ ( TQString::fromLatin1("KHexEdit/KBytesEdit"), TQString::null, Parent, Name );
}
}